# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Perl bindings for GNU LibIDN
Name:		perl-Net-LibIDN
Version:	0.12
Release:	46.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Net-LibIDN
Source0:	https://cpan.metacpan.org/modules/by-module/Net/Net-LibIDN-%{version}.tar.gz
Patch0:		Net-LibIDN-0.12-Respect-Config-s-cc-ccflags-and-ldflags.patch
Patch1:		Net-LibIDN-0.12-utf8.patch
# Module build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	libidn-devel >= 0.4.0
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Getopt::Long)
# Module Runtime
BuildRequires:	perl(AutoLoader)
BuildRequires:	perl(Carp)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
Perl bindings for GNU Libidn, a C library for handling Internationalized
Domain Names according to IDNA (RFC 3490), in a way very much inspired by
Turbo Fredriksson's PHP-IDN.

%prep
%setup -q -n Net-LibIDN-%{version}

# Use distribution CFLAGS for tests (#1242794, CPAN RT#105853)
%patch -P 0 -p1

# Re-code docs as UTF8
%patch -P 1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license Artistic
%doc Changes README
%{_mandir}/man3/Net::LibIDN.3*
%{perl_vendorarch}/Net/
%{perl_vendorarch}/auto/Net/

%changelog
* Wed Jul 12 2023 Paul Howarth <paul@city-fan.org> - 0.12-46
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 0.12-43
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 0.12-40
- Perl 5.34 rebuild

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 0.12-37
- Perl 5.32 rebuild

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 0.12-34
- Perl 5.30 rebuild

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 0.12-31
- Perl 5.28 rebuild

* Mon May 14 2018 Paul Howarth <paul@city-fan.org> - 0.12-30
- Rebuild for libidn 1.3.5 in Fedora 29 onwards

* Tue Mar 27 2018 Paul Howarth <paul@city-fan.org> - 0.12-29
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Tue Jun 13 2017 Paul Howarth <paul@city-fan.org> - 0.12-26
- Use distribution CFLAGS for tests (#1242794, CPAN RT#105853)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Tue Sep 13 2016 Paul Howarth <paul@city-fan.org> - 0.12-24
- Classify buildreqs by usage
- Simplify find commands using -delete

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 0.12-19
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 0.12-15
- Perl 5.18 rebuild

* Mon Jun 25 2012 Paul Howarth <paul@city-fan.org> - 0.12-9
- BR: perl(AutoLoader), perl(Carp), perl(Data::Dumper), perl(Encode),
  perl(Exporter) and perl(Test)
- Fix encoding in %%prep rather than %%install
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Mon Jun 27 2011 Paul Howarth <paul@city-fan.org> - 0.12-7
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.12-5
- Rebuild for perl 5.12.1 in Rawhide

* Thu Jun  3 2010 Paul Howarth <paul@city-fan.org> - 0.12-4
- Fix dist tag for RHEL-6 Beta

* Fri Feb 12 2010 Paul Howarth <paul@city-fan.org> - 0.12-3
- Dist tag for Rawhide no longer needs special-casing
- Use %%{?perl_default_filter} for provides filter

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> - 0.12-2
- Filter out unwanted provides for perl shared objects

* Fri Feb 27 2009 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12 (fixes for NetBSD and Windows)
- Update to SLES-compatible dist tag macros

* Sat Aug 30 2008 Paul Howarth <paul@city-fan.org> - 0.11-1
- Import from Fedora
- Update to 0.11
- Don't bother creating GPL license text since upstream doesn't
- Bring spec more into line with regular perl module template

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.10-2
- Rebuild for new perl

* Sun Feb 10 2008 Robert Scheck <robert@fedoraproject.org> 0.10-1
- Upgrade to 0.10

* Wed Aug 29 2007 Robert Scheck <robert@fedoraproject.org> 0.09-4
- Updated the license tag according to the guidelines

* Mon May 07 2007 Robert Scheck <robert@fedoraproject.org> 0.09-3
- Rebuild

* Thu Apr 26 2007 Robert Scheck <robert@fedoraproject.org> 0.09-2
- Added build requirement to perl(ExtUtils::MakeMaker)

* Sun Sep 03 2006 Robert Scheck <robert@fedoraproject.org> 0.09-1
- Upgrade to 0.0.9 and rebuild for Fedora Core 6

* Fri Jun 23 2006 Robert Scheck <robert@fedoraproject.org> 0.08-5
- Changes to match with Fedora Packaging Guidelines (#193960)

* Sun Dec 25 2005 Robert Scheck <robert@fedoraproject.org> 0.08-4
- Rebuilt against gcc 4.1 and libidn 0.6.0

* Fri Apr 01 2005 Robert Scheck <robert@fedoraproject.org> 0.08-3
- Some spec file cleanup

* Mon Mar 14 2005 Robert Scheck <robert@fedoraproject.org> 0.08-2
- Rebuilt against gcc 4.0

* Thu Jan 20 2005 Robert Scheck <robert@fedoraproject.org> 0.08-1
- Upgrade to 0.0.8

* Sun Oct 03 2004 Robert Scheck <robert@fedoraproject.org> 0.07-2
- Use perl(:MODULE_COMPAT_*) as requirement for perl
- Lots of spec file cleanups

* Mon May 24 2004 Robert Scheck <robert@fedoraproject.org> 0.07-1
- Upgrade to 0.0.7

* Mon Apr 05 2004 Robert Scheck <robert@fedoraproject.org> 0.06-1
- Upgrade to 0.0.6
- Initial spec file for Red Hat Linux and Fedora Core
